import gql from "graphql-tag"

// Pour la page index
export const LAST_EVENTS = gql`query LastEvents($start: Int64, $end: Int64) {
  membersCount(start: $start, end: $end) {
    idList {
      __typename
      member : id {
        __typename
        pubkey
        uid
        status
        hash
        limitDate
        history {
          __typename
          in
          block {
            __typename
            number
          }
        }
        received_certifications {
          __typename
          limit
        }
      }
      inOut
    },
    block {
      __typename
      number
    }
  }
} `

// Pour la page previsions/index
export const PREVISIONS = gql`query GetDossiers {
    now {
      number
      bct
      __typename
    }
    parameter(name: sigQty) {
      sigQty: value
      __typename
    }
    wwFile(full: true) {
      certifs_dossiers {
        ... on MarkedDatedCertification {
          datedCertification {
            date
            certification {
              from {
                uid
                __typename
              }
              to {
                uid
                __typename
              }
              expires_on
              __typename
            }
            __typename
          }
          __typename
        }
        ... on MarkedDossier {
          dossier {
            main_certifs
            newcomer {
              uid
              lastApplication {
                lastAppDate: bct
                __typename
              }
              distance: distanceE {
                value {
                  ratio
                  __typename
                }
                dist_ok
                __typename
              }
              __typename
            }
            date
            minDate
            expires_on: limit
            certifications {
              date
              certification {
                from {
                  uid
                  quality {
                    ratio
                    __typename
                  }
                  __typename
                }
                expires_on
                __typename
              }
              __typename
            }
            __typename
          }
          __typename
        }
      }
      __typename
    }
  }`

// Pour la page previsions/_hash
export const PREVISION = gql`query SearchForecast($hash: Hash!) {
    idFromHash(hash: $hash) {
        ...memberAttributes
        pubkey
        isLeaving
        sentry
        minDate
        minDatePassed
        membership_pending
        limitDate
        distance {
            __typename
            value {
                __typename
                ratio
            }
            dist_ok
        }
        received_certifications {
            __typename
            certifications {
                __typename
                from {
                    ...memberAttributes
                }
                expires_on
            }
        }
        sent_certifications {
            __typename
            to {
                ...memberAttributes
            }
            expires_on
        }
    }
}
fragment memberAttributes on Identity {
    __typename
    uid
    hash
    status
    quality {
        ratio
    }
    received_certifications {
        limit
    }
}`

// Pour la page previsions/newcomers
export const NEWCOMERS = gql`query GetNewcomers{
    wwResult {
        __typename
        permutations_nb
        dossiers_nb
        certifs_nb
        forecastsByNames {
            __typename
            member : id {
                __typename
                pubkey
                uid
                status
                hash
                limitDate
                received_certifications {
                    __typename
                    limit
                }
            }
            date
            after
            proba
        }
    }
} `

// Pour la page membres/index
export const SEARCH_MEMBERS = gql`query SearchMember($hint: String) {
    idSearch(with: {hint: $hint}) {
        __typename
        ids {
            __typename
            pubkey
            uid
            status
            hash
            limitDate
            received_certifications {
                __typename
                limit
            }
        }
    }
} `

// Pour la page membres/_hash
export const SEARCH_MEMBER = gql`query SearchMemberWithHash($hash: Hash!) {
    idFromHash(hash: $hash) {
        ...attr
        pubkey
        isLeaving
        sentry
        minDate
        minDatePassed
        membership_pending
        limitDate
        distance {
          __typename
          value {
            __typename
            ratio
          }
          dist_ok
        }
        received_certifications {
          __typename
          certifications {
            __typename
            from {
              ...attr
            }
            expires_on
          }
        }
        sent_certifications {
          __typename
          to {
            ...attr
          }
          expires_on
        }
    }
}
fragment attr on Identity {
  __typename
  uid
  hash
  status
  quality {
    __typename
    ratio
  }
  received_certifications {
    __typename
    limit
  }
}`